Learn R Programming

fixedincome (version 0.0.5)

as.spotrate: Coerce to SpotRate

Description

Coerce character objects to SpotRate class

Usage

as.spotrate(x, ...)

# S4 method for character as.spotrate(x, simplify = TRUE)

# S4 method for SpotRateCurve as.spotrate(x, ...)

# S4 method for ForwardRate as.spotrate(x, ...)

Value

A SpotRate object created from a string.

Arguments

x

a character with SpotRate specification.

...

additional arguments

simplify

a boolean indicating whether to simplify SpotRate creation or not. Defaults to TRUE.

Details

The character representation of a SpotRate is as follows:

"RATE COMPOUNDING DAYCOUNT CALENDAR"

where:

  • RATE is a numeric value

  • COMPOUNDING is one of the following: simple, discrete, continuous

  • DAYCOUNT is a valid day count rule, pex. business/252, see Daycount.

  • CALENDAR is the name of a bizdays calendar.

simplify check if compounding, daycount and calendar are the same for all given characters. If it is true the returned object is a SpotRate otherwise a list with SpotRate objects is returned.

Examples

Run this code

as.spotrate(c(
  "0.06 simple actual/365 actual",
  "0.11 discrete business/252 actual"
))

Run the code above in your browser using DataLab