# S4 method for character
as.spotrate(x, simplify = TRUE)
# S4 method for SpotRateCurve
as.spotrate(x, ...)
# S4 method for ForwardRate
as.spotrate(x, ...)
Value
A SpotRate object created from a string.
Arguments
x
a character with SpotRate specification.
...
additional arguments
simplify
a boolean indicating whether to simplify SpotRate creation
or not. Defaults to TRUE.
Details
The character representation of a SpotRate is as follows:
"RATE COMPOUNDING DAYCOUNT CALENDAR"
where:
RATE is a numeric value
COMPOUNDING is one of the following:
simple, discrete, continuous
DAYCOUNT is a valid day count rule, pex. business/252,
see Daycount.
CALENDAR is the name of a bizdays calendar.
simplify check if compounding, daycount and calendar are the same for
all given characters.
If it is true the returned object is a SpotRate otherwise a list with
SpotRate objects is returned.