powered by
as.term coerces a character vector to a Term object.
as.term
as.term(x, ...)
A Term object created from a string.
Term
a character to be coerced to a Term.
additional arguments. Currently unused.
The string representation of the Term class follows the layout:
NUMBER UNITS
where units is one of: days, months, years.
t <- as.term("6 months")
Run the code above in your browser using DataLab