dib returns the days in base, that is the number of days used to
define one year.
Usage
dib(x)
Value
A numeric with daycount's days in base, the number of days in a year
used in the convention.
Arguments
x
a Daycount object.
Details
The method dib returns the days in base for a daycount convention.
Since we work with annual rates the days in base define the amount of days
in a year used in the convention.