powered by
Fancy ggplot for SpotRateCurve object with custom axis, title
ggspotratecurveplot( curve, title = NULL, subtitle = NULL, caption = NULL, curve.name = NULL, curve.interpolation = FALSE, curve.x.axis = c("dates", "terms"), ... )
SpotRateCurve object
plot title
plot subtitle
plot caption
Curve's name, if not provided curve's refdate is used.
logical indicating to use daily interpolation instead of curve points. Defaults to FALSE.
FALSE
x axis can be presented with a numeric scale representing business days (terms) or dates (dates). Defaults to dates.
terms
dates
additional arguments (not used)
if (FALSE) { terms <- c(1, 11, 26, 27, 28) rates <- c(0.0719, 0.056, 0.0674, 0.0687, 0.07) curve <- spotratecurve(rates, terms, "discrete", "actual/365", "actual") ggspotratecurveplot(curve) }
Run the code above in your browser using DataLab