powered by
Compute the SpotRateCurve terms as Date objects, according to the curve's reference date.
maturities(x)
A vector of Date objects that represent the curve's terms and using curve's refdate as a starting point.
Date
terms
refdate
a SpotRateCurve object.
terms <- c(1, 11, 26, 27, 28) rates <- c(0.0719, 0.056, 0.0674, 0.0687, 0.07) curve <- spotratecurve(rates, terms, "discrete", "actual/365", "actual") maturities(curve)
Run the code above in your browser using DataLab